@@ -43,7 +43,11 @@ module SccProxy
       # to SCC.
       # SCC will make sure to handle the data correctly. This removes the need
       # to adapt here if information send by the client changes.
+      # login and password are set to instance identifier (system_token) so SCC use those values
+      # instead of creating a random one
       scc_req_body = {
+        login: system_token,
+        password: system_token,
         hostname: params['hostname'],
         hwinfo: params['hwinfo'],
         byos_mode: params['proxy_byos_mode']
@@ -284,40 +288,45 @@ module SccProxy
           auth_header = request.headers.fetch('HTTP_AUTHORIZATION', nil)
           system_information = hwinfo_params[:hwinfo].to_json
           instance_data = params.fetch(:instance_data, nil)
-          system_token = InstanceVerification.provider.new(nil, nil, nil, params['instance_data']).instance_identifier
+          instance_identifier = InstanceVerification.provider.new(nil, nil, nil, params['instance_data']).instance_identifier
+          system_values = {
+            hostname: params[:hostname],
+            system_information: system_information,
+            instance_data: instance_data,
+            system_token: instance_identifier,
+            # using instance identifier instead of 'SCC_FOO' as login
+            # it is a unique value per instance across all CSPs
+            login: instance_identifier
+          }
           if has_no_regcode?(auth_header)
+            # NON BYOS case
             # no token sent to check with SCC
-            # standard announce case
-            @system = System.create!(
-              hostname: params[:hostname],
-              system_information: system_information,
-              proxy_byos_mode: :payg,
-              instance_data: instance_data,
-              system_token: system_token
-            )
+            system_values[:proxy_byos_mode] = :payg
           else
             request.request_parameters['proxy_byos_mode'] = 'byos'
-            response = SccProxy.announce_system_scc(auth_header, request.request_parameters, system_token)
-            @system = System.create!(
-              system_token: system_token,
-              scc_system_id: response['id'],
-              login: response['login'],
-              password: response['password'],
-              hostname: params[:hostname],
-              proxy_byos_mode: :byos,
-              proxy_byos: true,
-              system_information: system_information,
-              instance_data: instance_data
+            response = SccProxy.announce_system_scc(auth_header, request.request_parameters, instance_identifier)
+            system_values.merge!(
+              {
+                scc_system_id: response['id'],
+                password: response['password'],
+                proxy_byos_mode: :byos,
+                proxy_byos: true
+              }
             )
           end
+          @system = System.create!(system_values)
           logger.info("System '#{@system.hostname}' announced")
           respond_with(@system, serializer: ::V3::SystemSerializer, location: nil)
         rescue *NET_HTTP_ERRORS => e
-          logger.error(
-            "Could not register system with regcode #{auth_header} " \
-              "to SCC: #{e.message}"
-          )
+          message = 'Could not register system'
+          message += " with regcode #{auth_header} to SCC" unless has_no_regcode?(auth_header)
+          logger.error("#{message}: #{e.message}")
           render json: { type: 'error', error: e.message }, status: status_code(e.message), location: nil
+        rescue InstanceVerification::Exception => e
+          message = 'Could not register system'
+          message += " with regcode #{auth_header} to SCC" unless has_no_regcode?(auth_header)
+          logger.error("#{message}: #{e.message}")
+          render json: { type: 'error', error: e.message }, status: :unprocessable_entity, location: nil
         end
 
         protected
@@ -377,8 +386,11 @@ module SccProxy
           logger.error(
             "Could not activate product for system with regcode #{params[:token]}" \
               "to SCC: #{e.message}"
-          )
+            )
           render json: { type: 'error', error: e.message }, status: status_code(e.message), location: nil
+        rescue InstanceVerification::Exception => e
+          logger.error("Could not activate product for system to SCC: #{e.message}")
+          render json: { type: 'error', error: e.message }, status: :unprocessable_entity, location: nil
         end
 
         def update_pubcloud_reg_code(encoded_reg_code)
@@ -520,18 +532,33 @@ module SccProxy
           end
         end
 
+        # rubocop:disable Metrics/CyclomaticComplexity
+        # rubocop:disable Metrics/PerceivedComplexity
         def find_system
           systems_with_token = @systems.select(&:system_token)
           if systems_with_token.empty?
+            found_iid = false
+            non_byos_systems = false
             @systems.each do |system|
               if system.payg? || system.hybrid?
+                non_byos_systems = true
                 # if PAYG or HYBRID and no system_token  =>
                 # update the system_token
-                iid = InstanceVerification.provider.new(nil, nil, nil, system.instance_data).instance_identifier
+                begin
+                  iid = InstanceVerification.provider.new(nil, nil, nil, system.instance_data).instance_identifier
+                rescue InstanceVerification::Exception => e
+                  logger.error("Could not find system (login #{system.login} instance identifier: #{e.message}")
+                  next
+                end
+                found_iid = true
                 system.update!(system_token: iid)
                 return system
               end
             end
+            logger.info('No PAYG or HYBRID systems') unless non_byos_systems
+
+            logger.info('No instance identifier found') if non_byos_systems && !found_iid
+
             return @systems.first
           end
 
@@ -558,6 +585,8 @@ module SccProxy
           end
           system
         end
+        # rubocop:enable Metrics/CyclomaticComplexity
+        # rubocop:enable Metrics/PerceivedComplexity
       end
     end
   end
