@@ -94,7 +94,7 @@ module ZypperAuth
           return true if @system.byos?
 
           instance_verified = InstanceVerification.verify_instance(request, logger, @system)
-          DataExport.handler.new(@system, request, params, logger).export_rmt_data if instance_verified
+          DataExport.handler.new(@system, request, params, logger).export_rmt_data if DataExport.handler.presence && instance_verified
 
           instance_verified
         end
