@@ -1,9 +1,12 @@
+require 'xz'
+
 class RMT::Mirror::Debian < RMT::Mirror::Base
   RELEASE_FILE_NAME = 'Release'.freeze
   SIGNATURE_FILE_NAME = 'Release.gpg'.freeze
   KEY_FILE_NAME = 'Release.key'.freeze
   INRELEASE_FILE_NAME = 'InRelease'.freeze
   NESTED_REPOSITORY_REGEX = %r{/dists/.*/$}.freeze
+  PACKAGE_INDEX_FILE_NAME = /Packages\.(gz|xz)/.freeze
 
 
   def mirror_implementation
@@ -54,7 +57,7 @@ class RMT::Mirror::Debian < RMT::Mirror::Base
   end
 
   def mirror_packages(metadata_refs)
-    packagelists = metadata_refs.select { |ref| File.basename(ref.local_path) == 'Packages.gz' }
+    packagelists = metadata_refs.select { |ref| File.basename(ref.local_path).match?(PACKAGE_INDEX_FILE_NAME) }
 
     packagelists.each do |packagelist|
       parse_package_list(packagelist).each do |ref|
@@ -70,9 +73,18 @@ class RMT::Mirror::Debian < RMT::Mirror::Base
     @logger.debug "Extracting package list from metadata file #{packagelist.local_path}"
     packages = []
     hdl = File.open(packagelist.local_path, 'rb')
+    ext = File.extname(packagelist.local_path)
+    ipackage_stream = ''
+
+    case ext
+    when '.gz'
+      ipackage_stream = Zlib::GzipReader.new(hdl)
+    when '.xz'
+      ipackage_stream = XZ::StreamReader.new(hdl)
+    end
 
     current = {}
-    Zlib::GzipReader.new(hdl).each_line do |line|
+    ipackage_stream.each_line do |line|
       if line == "\n"
         ref = file_reference(current[:filename], to: repository_path)
         ref.arch = current[:architecture]
@@ -108,7 +120,7 @@ class RMT::Mirror::Debian < RMT::Mirror::Base
       current[key.downcase.to_sym] = value.strip
     end
     packages
-  rescue Zlib::GzipFile::Error => e
+  rescue Zlib::GzipFile::Error, XZ::LZMAError => e
     message = _("Could not read '%{file}': %{error}" % { file: packagelist.local_path, error: e })
     raise RMT::Mirror::Exception.new(message)
   ensure
@@ -152,7 +164,7 @@ class RMT::Mirror::Debian < RMT::Mirror::Base
 
   def is_mandatory?(file_ref)
     # This check is needed to separate what files are mandatory to download
-    # We expect only Packages.gz to always be present
-    File.basename(file_ref.relative_path) == 'Packages.gz'
+    # We expect only compressed package indices to always be present
+    File.basename(file_ref.relative_path).match?(PACKAGE_INDEX_FILE_NAME)
   end
 end
